@@ -164,7 +164,7 @@ pub(crate) unsafe fn get_cass_future_error(rc: CassError_, inner: *mut _Future)
 }
 
 /// A Cassandra failure error code.
-#[derive(Debug, Eq, PartialEq)]
+#[derive(Debug, Eq, PartialEq, Copy, Clone, Hash)]
 #[allow(missing_docs)] // Meanings are defined in CQL documentation.
 #[allow(non_camel_case_types)] // Names are traditional.
 pub enum CassErrorCode {
