@@ -75,7 +75,7 @@ use std::str;
 
 
 /// The type of a Cassandra value.
-#[derive(Debug, Eq, PartialEq)]
+#[derive(Debug, Eq, PartialEq, Copy, Clone, Hash)]
 #[allow(missing_docs)] // Meanings are defined in CQL documentation.
 #[allow(non_camel_case_types)] // Names are traditional.
 pub enum ValueType {
@@ -142,6 +142,11 @@ enhance_nullary_enum!(ValueType, CassValueType_, {
 /// A single primitive value or a collection of values.
 pub struct Value(*const _CassValue);
 
+// The underlying C type is read-only so thread-safe.
+unsafe impl Send for Value {}
+unsafe impl Sync for Value {}
+
+
 impl Protected<*const _CassValue> for Value {
     fn inner(&self) -> *const _CassValue { self.0 }
     fn build(inner: *const _CassValue) -> Self { Value(inner) }
